unit Unit1;

interface

uses
  System.SysUtils, System.Types, System.UITypes, System.Classes, System.Variants,
  FMX.Types, FMX.Controls, FMX.Forms, FMX.Dialogs, FMX.StdCtrls, FMX.Edit,
  FMX.Media;

type
  TForm1 = class(TForm)
    Label1: TLabel;
    Label2: TLabel;
    NameEdit: TEdit;
    EnabledSwitch: TSwitch;
    SliderBar: TTrackBar;
    ReadButton: TButton;
    WriteButton: TButton;
    ReadIniButton: TButton;
    WriteIniButton: TButton;
    CameraComponent1: TCameraComponent;
    procedure ReadButtonClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure WriteButtonClick(Sender: TObject);
    procedure ReadIniButtonClick(Sender: TObject);
    procedure WriteIniButtonClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

uses
  iOSapi.Foundation, Macapi.ObjectiveC, Apple.Inifiles;

{$R *.fmx}

procedure TForm1.FormCreate(Sender: TObject);
var
  lDict: NSMutableDictionary;
  lDefaults: NSUserDefaults;
begin
  lDict := TNSMutableDictionary.Create;
  try
    lDict.setValue(
      (NSStr('Hello from Delphi!') as ILocalObject).GetObjectID,
      NSStr('name_preference'));
    lDict.setValue(TNSNumber.OCClass.numberWithBool(True), NSStr('enabled_preference'));
    lDict.setValue(TNSNumber.OCClass.numberWithDouble(0.5), NSStr('slider_preference'));

    lDefaults := TNSUserDefaults.Wrap(TNSUserDefaults.OCClass.standardUserDefaults);
    lDefaults.registerDefaults(lDict);
  finally
    lDict.release;
  end;
end;

procedure TForm1.ReadButtonClick(Sender: TObject);
var
  lDefaults: NSUserDefaults;
begin
  lDefaults := TNSUserDefaults.Wrap(TNSUserDefaults.OCClass.standardUserDefaults);
  NameEdit.Text := UTF8ToString(
    lDefaults.stringForKey(NSStr('name_preference')).UTF8String);
  EnabledSwitch.IsChecked := lDefaults.boolForKey(NSStr('enabled_preference'));
  SliderBar.Value := lDefaults.doubleForKey(NSStr('slider_preference'));
end;

procedure TForm1.ReadIniButtonClick(Sender: TObject);
var
  lIni: TUserIniFile;
begin
  lIni := TUserIniFile.Create;
  NameEdit.Text := lIni.ReadString('name_preference', 'Hello from Delphi!');
  EnabledSwitch.IsChecked := lIni.ReadBool('enabled_preference', True);
  SliderBar.Value := lIni.ReadFloat('slider_preference', 0.5);
end;

procedure TForm1.WriteButtonClick(Sender: TObject);
var
  lDefaults: NSUserDefaults;
begin
  lDefaults := TNSUserDefaults.Wrap(TNSUserDefaults.OCClass.standardUserDefaults);
  lDefaults.setObject(
    (NSStr(NameEdit.Text) as ILocalObject).GetObjectID,
    NSStr('name_preference'));
  lDefaults.setBool(EnabledSwitch.IsChecked, NSStr('enabled_preference'));
  lDefaults.setFloat(SliderBar.Value, NSStr('slider_preference'));
end;

procedure TForm1.WriteIniButtonClick(Sender: TObject);
var
  lIni: TUserIniFile;
begin
  lIni := TUserIniFile.Create;
  lIni.WriteString('name_preference', NameEdit.Text);
  lIni.WriteBool('enabled_preference', EnabledSwitch.IsChecked);
  lIni.WriteFloat('slider_preference', SliderBar.Value);
end;

end.
